@@ -1,8 +1,8 @@
 package WebService::GData::Node::GD::FeedLink;
 use WebService::GData::Node::GD;
 
-set_xml_meta(
-   attributes=>[qw(rel href countHint)],
+set_meta(
+   attributes=>[qw(rel href countHint readOnly)],
    is_parent=>0
 );
 
