@@ -1,7 +1,8 @@
 package WebService::GData::Node::Media;
-
+use WebService::GData::Constants qw/:namespace/;
 use WebService::GData::Node;
 
+
 sub import {
     my $package = caller;
     return if($package->isa(__PACKAGE__)||$package eq 'main'||$package!~m/Media::/);
@@ -13,7 +14,8 @@ sub import {
 }
 }
 
-sub root_name {'media'};
 
+sub namespace_prefix {MEDIA_NAMESPACE_PREFIX};
+sub namespace_uri { MEDIA_NAMESPACE_URI }
 
 1;
\ No newline at end of file
